@@ -1058,16 +1058,18 @@ Sv_DuplicateObj(
      */
 
     if (objPtr->bytes == NULL) {
-        dupPtr->bytes = NULL;
+	if (dupPtr->bytes != Sv_tclEmptyStringRep) {
+	    dupPtr->bytes = NULL;
+	}
     } else if (objPtr->bytes != Sv_tclEmptyStringRep) {
-        /* A copy of TclInitStringRep macro */
-        dupPtr->bytes = (char*)ckalloc((unsigned)objPtr->length + 1);
-        if (objPtr->length > 0) {
-            memcpy((void*)dupPtr->bytes,(void*)objPtr->bytes,
-                   (unsigned)objPtr->length);
-        }
-        dupPtr->length = objPtr->length;
-        dupPtr->bytes[objPtr->length] = '\0';
+	/* A copy of TclInitStringRep macro */
+	dupPtr->bytes = (char*)ckalloc((unsigned)objPtr->length + 1);
+	if (objPtr->length > 0) {
+	    memcpy(dupPtr->bytes, objPtr->bytes,
+		    objPtr->length);
+	}
+	dupPtr->length = objPtr->length;
+	dupPtr->bytes[objPtr->length] = '\0';
     }
 
     return dupPtr;
@@ -1185,7 +1187,7 @@ SvObjObjCmd(
      * Format the command name
      */
 
-    sprintf(buf, "::%p", (int*)svObj);
+    snprintf(buf, sizeof(buf), "::%p", (int*)svObj);
     svObj->aolSpecial = (arg != NULL);
     Tcl_CreateObjCommand(interp, buf, SvObjDispatchObjCmd, svObj, NULL);
     Tcl_ResetResult(interp);
@@ -2074,7 +2076,7 @@ SvLockObjCmd(
         char msg[32 + TCL_INTEGER_SPACE];
         /* Next line generates a Deprecation warning when compiled with Tcl 8.6.
          * See Tcl bug #3562640 */
-        sprintf(msg, "\n    (\"eval\" body line %d)", Tcl_GetErrorLine(interp));
+        snprintf(msg, sizeof(msg), "\n    (\"eval\" body line %d)", Tcl_GetErrorLine(interp));
         Tcl_AddErrorInfo(interp, msg);
     }
 
